@@ -17,19 +17,18 @@ class UnknownDataSetError(BaseException):
     '''Exception for when trying to query from an invalid data set.'''
 
 
-def format_url(uid: str, data_format='fasta', dataset='default'):
-    if dataset == 'default':
-        return UNIPROT_URL + uid + '/.' + data_format
-    elif dataset in KNOWN_DATASETS:
-        return BASE_API_URL + dataset + '/' + uid + '/.' + data_format 
+def format_url(query: str, data_format='fasta', dataset='uniprotkb'):
+    if dataset in KNOWN_DATASETS:
+        return BASE_API_URL + dataset + '/' + query + '.' + data_format 
     else:
         raise UnknownDataSetError()
 
 
-def fetch(uid: str, data_format='fasta', dataset='default'):
+def fetch(query: str, data_format='fasta', dataset='uniprotkb'):
     '''Downloads the protein sequence from uniprot as a .fasta file.'''
     try:
-        url = format_url(uid, data_format, dataset)
+        url = format_url(query, data_format, dataset)
+        print(f"url: {url}")
     except UnknownDataSetError:
         print(f"Error - Data set: {dataset} is unknown to uniprot.")
         sys.exit(-1)
